@@ -16,9 +16,10 @@ from ._tokenizer import Tokenizer, TokenType
 class ResampledFormulaBuilder(FormulaBuilder):
     """Provides a way to build a FormulaEngine from resampled data streams."""
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         namespace: str,
+        formula_name: str,
         channel_registry: ChannelRegistry,
         resampler_subscription_sender: Sender[ComponentMetricRequest],
         metric_id: ComponentMetricId,
@@ -28,6 +29,7 @@ class ResampledFormulaBuilder(FormulaBuilder):
         Args:
             namespace: The unique namespace to allow reuse of streams in the data
                 pipeline.
+            formula_name: A name for the formula.
             channel_registry: The channel registry instance shared with the resampling
                 and the data sourcing actors.
             resampler_subscription_sender: A sender to send metric requests to the
@@ -38,23 +40,21 @@ class ResampledFormulaBuilder(FormulaBuilder):
         self._resampler_subscription_sender = resampler_subscription_sender
         self._namespace = namespace
         self._metric_id = metric_id
-        super().__init__()
+        super().__init__(formula_name)
 
-    async def _get_resampled_receiver(self, component_id: int) -> Receiver[Sample]:
+    async def _get_resampled_receiver(
+        self, component_id: int, metric_id: ComponentMetricId
+    ) -> Receiver[Sample]:
         """Get a receiver with the resampled data for the given component id.
 
-        This receiver would contain data for the `metric_id` specified when creating the
-        `ResampledFormulaBuilder` instance.
-
         Args:
             component_id: The component id for which to get a resampled data receiver.
+            metric_id: A metric ID to fetch for all components in this formula.
 
         Returns:
             A receiver to stream resampled data for the given component id.
         """
-        request = ComponentMetricRequest(
-            self._namespace, component_id, self._metric_id, None
-        )
+        request = ComponentMetricRequest(self._namespace, component_id, metric_id, None)
         await self._resampler_subscription_sender.send(request)
         return self._channel_registry.new_receiver(request.get_channel_name())
 
@@ -68,7 +68,7 @@ class ResampledFormulaBuilder(FormulaBuilder):
             nones_are_zeros: Whether to treat None values from the stream as 0s.  If
                 False, the returned value will be a None.
         """
-        receiver = await self._get_resampled_receiver(component_id)
+        receiver = await self._get_resampled_receiver(component_id, self._metric_id)
         self.push_metric(f"#{component_id}", receiver, nones_are_zeros)
 
     async def from_string(
